/*
 * ********************************************************************************************************************
 *
 *                      :*$@@%$*:                         ;:                ;;    ;;
 *                    :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                   :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                   =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                   =@*                                  %!              @ $= % %@=   =%@!      %=
 *              *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *            %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *          ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *          $@*   ;@@@%=!:                *@*
 *          =@$    ;;;!=%@@@@=!           =@!
 *           %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *            ;%@@$=$@@%*       *@@@$=%@@%;
 *               ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

import { FloorScene } from "./FloorScene";
import { SMouseEvent } from "@sybotan-web/graphy/lib";
import { SColor, SPoint, SRect } from "@sybotan-web/draw/lib";
import { SceneMarkItem } from "./items/SceneMarkItem";

/**
 * 划分业务空间
 *
 * @author 郝建龙
 */
export class DivideFloorScene extends FloorScene {
    /** 是否开启用户标记     */
    _isMarking: boolean = false;
    get isMarking(): boolean {
        return this._isMarking;
    } // Get isMarking
    set isMarking(v: boolean) {
        if (this._isMarking === v) {
            return;
        }
        this._isMarking = v;
    } // Set isMarking

    /**
     * 构造函数
     *
     * @param   data
     */
    constructor() {
        super();
    } // Constructor

    /** 清除蒙版    */
    clearSceneMark(): void {
        if (this.grabItem) {
            this.removeItem(this.grabItem);
            this.grabItem = null;
            this.isMarking = false;
        }
    } // Function clearSceneMark()

    /**
     * 点击事件
     *
     * @param   event   保存事件参数
     * @return  boolean
     */
    onMouseDown(event: SMouseEvent): boolean {
        console.log(arguments)
        if (this.isMarking) {
            if (this.grabItem) {
                this.grabItem.onMouseDown(event);
            } else {
                let point = new SPoint(event.x, event.y);
                let sceneMark = new SceneMarkItem(null, point);
                this.addItem(sceneMark);
                this.grabItem = sceneMark;
            }
        } else {
            super.onMouseDown(event);
        }
        return false;
    } // Function onClick()

    /***
     * 键盘按下事件
     *
     * @param      event   保存事件参数
     */
    onKeyUp(event: KeyboardEvent): void {
        if (this.isMarking) {
            if (this.grabItem) {
                this.grabItem.onKeyUp(event);
            }
        } else {
            super.onKeyUp(event);
        }
    }
} // Class DivideFloorScene
