/*
 * ********************************************************************************************************************
 *
 *                      :*$@@%$*:                         ;:                ;;    ;;
 *                    :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                   :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                   =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                   =@*                                  %!              @ $= % %@=   =%@!      %=
 *              *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *            %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *          ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *          $@*   ;@@@%=!:                *@*
 *          =@$    ;;;!=%@@@@=!           =@!
 *           %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *            ;%@@$=$@@%*       *@@@$=%@@%;
 *               ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

import { SGraphyItem, SMouseEvent } from "@sybotan-web/graphy/lib";
import { SColor, SPainter, SPoint, SRect } from "@sybotan-web/draw/lib";
import { VirtualWall } from "../types/VirtualWall";
import { Opt } from "../types/Opt";

/**
 * 墙item
 *
 * @author  郝建龙
 */
export class VirtualWallItem extends SGraphyItem {
    /** 虚拟墙数据   */
    data: VirtualWall;
    /** 虚拟墙轮廓线坐标list  */
    private readonly pointArr: SPoint[] = [];

    /**
     * 构造函数
     *
     * @param parent    指向父对象
     * @param data      虚拟墙数据
     */
    constructor(parent: SGraphyItem | null, data: VirtualWall) {
        super(parent);
        this.data = data;
        if (this.data.OutLine.length) {
            this.pointArr = this.data.OutLine[0].map(t => {
                return new SPoint(t.X, -t.Y);
            });
        }
    } // Constructor

    /**
     * Item绘制操作
     *
     * @param   painter       painter对象
     * @param   rect          绘制区域
     */
    onDraw(painter: SPainter, rect?: SRect): void {
        if (this.visible) {
            painter.pen.lineWidth = 100;
            painter.pen.color = Opt.virtualWallColor;
            painter.pen.lineDash = [200, 200];
            painter.drawPolyline(this.pointArr);
        }
    } // Function onDraw()
} // Class VirtualWall
