/*
 * ********************************************************************************************************************
 *
 *                      :*$@@%$*:                         ;:                ;;    ;;
 *                    :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                   :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                   =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                   =@*                                  %!              @ $= % %@=   =%@!      %=
 *              *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *            %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *          ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *          $@*   ;@@@%=!:                *@*
 *          =@$    ;;;!=%@@@@=!           =@!
 *           %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *            ;%@@$=$@@%*       *@@@$=%@@%;
 *               ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

import { SGraphyItem, SMouseEvent } from "@sybotan-web/graphy/lib";
import { SColor, SPainter, SPoint, SRect } from "@sybotan-web/draw/lib";
import { Wall } from "../types/Wall";
import { Opt } from "../types/Opt";
import {Point} from "../types/Point";

/**
 * 墙item
 *
 * @author  郝建龙
 */
export class WallItem extends SGraphyItem {
    /** 墙数据 */
    data: Wall;
    /** 墙轮廓线坐标list  */
    private readonly pointArr: SPoint[][] = [];

    /**
     * 构造函数
     *
     * @param parent    指向父对象
     * @param data      墙数据
     */
    constructor(parent: SGraphyItem | null, data: Wall) {
        super(parent);
        this.data = data;
        if (this.data.OutLine.length) {
            this.pointArr = this.data.OutLine.map(t => {
                let tempArr = t.map(it => {
                    return new SPoint(it.X, -it.Y);
                });
                return tempArr;
            });
        }
    } // Constructor

    /**
     * Item绘制操作
     *
     * @param   painter       painter对象
     * @param   rect          绘制区域
     */
    onDraw(painter: SPainter, rect?: SRect): void {
        if (this.visible) {
            painter.pen.color = Opt.wallColor;
            painter.pen.lineWidth = 10;
            painter.brush.color = Opt.wallColor;
            this.pointArr.map(t => {
                painter.drawPolygon(t);
            });
        }
    } // Function onDraw()
} // Class WallItem
